@@ -124,6 +124,10 @@ class PagamentoBanco(models.Model):
             self.contrato_id = self.conta.contrato_id
         super(PagamentoBanco, self).save(*args, **kwargs)
 
+    @property
+    def cpf_cnpj(self):
+        return self.cpf or self.cnpj or None
+
 
 class FormaPagamentoConfiguracao(models.Model):
     """Configuração da forma de pagamento."""
