@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# TODO: Faltou adicionar o controle de produtos
 
 from django.db import models
+from jsonfield import JSONField
 
 
 class DadosCobranca(models.Model):
@@ -57,16 +57,22 @@ class DadosCobrancaCartao(models.Model):
 
 class Fatura(models.Model):
 
+    FORMAS_DE_PAGAMENTO = [
+        ('BOLETO','Boleto'),
+        ('CARTAO DE CREDITOC','Cartão de Crédito')
+    ]
+
     id = models.AutoField(db_column="fatura_id", primary_key=True)
     situacao = models.CharField(db_column="fatura_situacao")
     data_vencimento = models.DateField(db_column="fatura_data_vencimento")
     data_tolerancia = models.DateField(db_column="fatura_data_tolerancia")
     data_pagamento = models.DateField(db_column="fatura_data_pagamento", default=None)
     valor_cheio = models.DecimalField(db_column="fatura_valor_cheio", decimal_places=2, max_digits=12)
-    valor_pcc_imposto = models.DecimalField(db_column="fatura_valor_pcc_imposto", decimal_places=2, max_digits=12)
+    valor_impostos = models.DecimalField(db_column="fatura_valor_impostos", decimal_places=2, max_digits=12)
+    valor_impostos_json = JSONField(db_column='fatura_valor_impostos_json', null=True, default=None)
     valor_cobrado = models.DecimalField(db_column="fatura_valor_cobrado", decimal_places=2, max_digits=12)
     valor_pago = models.DecimalField(db_column="fatura_valor_pago", decimal_places=2, max_digits=12)
-    dados_forma_pagamento = models.CharField(db_column="fatura_dados_forma_pagamento")
+    dados_forma_pagamento = models.CharField(db_column="fatura_dados_forma_pagamento", choices=FORMAS_DE_PAGAMENTO)
     dados_tipo_pessoa = models.CharField(db_column="fatura_dados_tipo_pessoa")
     dados_email_nfe = models.CharField(db_column="fatura_dados_email_nfe")
     dados_nome_responsavel = models.CharField(db_column="fatura_dados_nome_responsavel")
@@ -89,6 +95,8 @@ class Fatura(models.Model):
     controle_lancamento_numero = models.IntegerField(db_column="fatura_controle_lancamento_numero", default=None)
     controle_quitada = models.IntegerField(db_column="fatura_controle_quitada", default=None)
     controle_nota_fiscal = models.IntegerField(db_column="fatura_controle_nota_fiscal", default=None)
+    json = JSONField(db_column='fatura_json', null=True, default=None)
+    observacao = models.TextField(db_column="fatura_observacao")
     data_criacao = models.DateTimeField(db_column="fatura_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="fatura_data_modificacao", auto_now=True)
 
@@ -109,6 +117,7 @@ class FaturaItem(models.Model):
     referencia_id = models.IntegerField(db_column="fatura_item_referencia_id")
     referencia_situacao_principal = models.CharField(db_column="fatura_item_referencia_situacao_principal")
     referencia_situacao_complementar = models.CharField(db_column="fatura_item_referencia_situacao_complementar")
+    json = JSONField(db_column='fatura_item_json', null=True, default=None)
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
     fatura = models.ForeignKey("Fatura", db_column="fatura_id")
@@ -134,7 +143,6 @@ class Plano(models.Model):
     nome = models.TextField(db_column="plano_nome")
     valor = models.DecimalField(db_column="plano_valor")
     indice = models.IntegerField(db_column="plano_indice", default=0)
-    intervalo = models.IntegerField(db_column="plano_intervalo", default=0)
     controle_trafego = models.IntegerField(db_column="plano_controle_trafego", default=0)
     controle_visitas = models.IntegerField(db_column="plano_controle_visitas", default=0)
     controle_produtos = models.IntegerField(db_column="plano_controle_produtos", default=0)
@@ -161,9 +169,23 @@ class PlanoAssinatura(models.Model):
     data_modificacao = models.DateTimeField(db_column="plano_assinatura_data_modificacao", auto_now=True)
 
     conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
-    contrato = models.ForeignKey("plataforma.Contrato", db_column="contrato_id")
     plano = models.ForeignKey("Plano", db_column="plano_id")
     fatura = models.ForeignKey("Fatura", db_column="fatura_id")
 
     class Meta:
         db_table = u"faturamento\".\"tb_plano_assinatura"
+
+
+class Consumo(models.Model):
+
+    id = models.AutoField(db_column="plano_assinatura_id", primary_key=True)
+    data = models.DateField(db_column="consumo_data", null=False, default=None)
+    data_modificacao = models.DateTimeField(db_column="consumo_data_modificacao", auto_now=True)
+
+    trafego = models.BigIntegerField(db_column="consumo_trafego", default=0)
+    visitas = models.BigIntegerField(db_column="consumo_visitas", default=0)
+
+    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
+
+    class Meta:
+        db_table = u"faturamento\".\"tb_consumo"
\ No newline at end of file
