@@ -18,7 +18,7 @@ class PedidoVendaSituacao(models.Model):
     SITUACAO_PRONTO_RETIRADA = 13
     SITUACAO_PEDIDO_ENTREGUE = 14
     SITUACAO_PEDIDO_EM_SEPARACAO = 15
-    SITUACAO_PAGTO_CHARGED_BACK = 16
+    SITUACAO_PAGTO_CHARGEBACK = 16
 
     id = models.AutoField(db_column="pedido_venda_situacao_id", primary_key=True)
     nome = models.CharField(db_column="pedido_venda_situacao_nome", max_length=64)
